********************************************************************
* This do-file takes as input the following data from IPUMS USA (usa.ipums.org):
* 	1980 Census (5% state)
* 	2000 Census (5%)
* 	2016 ACS
* It imposes our sample restrictions and generates additional variables
* Output: main_dataset_clean.dta (individual-level dataset)
********************************************************************
 
*** DATA CLEANING ***

use "orig/[ORIGINAL DATA FROM IPUMS]", clear

*** Variables needed:
keep year age sex gq empstat* educ* race hispan bpl incwage occ uhrswork wkswork* perwt  
 
*** Replace codes for missing values ***

*** incwage
replace incwage=. if incwage==999999

* Need adjustment for top-coded wage income in 1980: Multiply by 1.4
* Top-coded values for later years are already imputed as described here:
* https://usa.ipums.org/usa-action/variables/INCWAGE#codes_section
gen incwage_top = incwage
replace incwage_top = 1.4*incwage if year==1980 & incwage==75000


*** educ
replace educ=. if educd==1
replace educd=. if educd==1

*** empstat
replace empstat=. if empstat==0


*** Generate education groups variables (4 categories) ***
	* HS dropout:
gen educ_grp = 1 if educ<=5
	* HS grad (note that this includes "12th grade, no diploma" and 
	* "ged or alternative credential", 
	* but excludes "some college, but less than 1 year" -- see educd variable):
replace educ_grp = 2 if educ==6 & educd!=65
	* Some Col:
replace educ_grp = 3 if educd==65
replace educ_grp = 3 if educ>=7 & educ<=9
	* Col Grad:
replace educ_grp = 4 if educ>=10 & educ<.
label define educ_grp_lbl 1 "HS Dropout" 2 "HS Grad" 3 "Some College" ///
	4 "College Grad"
label var educ_grp "Education (4 categories)"

*** Hispanic indicator ***
gen hispanic=(hispan!=0)
label var hispanic "Indicator for hispanic origin"


*** OCCUPATION CODES ***
replace occ=. if occ==0
*** Generate coding system indicator ***;
gen coc="1980s" if year==1980
replace coc="1990s" if year==1990
replace coc="2000s" if year>=2000 & year<=2009
replace coc="2010s" if year>=2010 & year<2018
replace coc="2018" if year>=2018
label var coc "Census Occupation Coding System"
	* NOTE: The ACS codes are a slightly more aggregated version of the 
	* standard Census codes, so basically the only issue will be that a few
	* Census codes will be missing

* Crosswalk to occ1990dd (Dorn codes)
gen occ80=occ if coc=="1980s"
merge m:1 occ80 using "crosswalks/occ80to_mo_dd", ///
	keepusing(occ1990dd) nogen keep(1 3 4 5) update
tab occ80 if occ80<. & occ1990dd==.
drop occ80

gen occ00=occ if coc=="2000s"
merge m:1 occ00 using "crosswalks/occ00to_mo_dd", ///
	keepusing(occ1990dd) nogen keep(1 3 4 5) update
tab occ00 if occ00<. & occ1990dd==.
drop occ00

gen occ2010=occ if coc=="2010s"
merge m:1 occ2010 using "crosswalks/occ10to_00_mo_dd", ///
	keepusing(occ1990dd) nogen keep(1 3 4 5) update
tab occ2010 if occ2010<. & occ1990dd==.
drop occ2010

label var occ1990dd "David Dorn's occupation codes"


*** Generate hours worked last year
* In all years, uhrswork indicates the usual hours per week (top coded at 99)
* For years where available, use wkswork1, which is the number of weeks worked in the
* previous year
gen hours = uhrswork*wkswork1 if wkswork1!=0 & uhrswork!=0 & year>=1980 & year<=2007
replace hours = uhrswork*wkswork1 if wkswork1!=0 & uhrswork!=0 & year>=2019
* For years from 2008 to 2018, we only have wkswork2, which is the number of weeks
* worked in the previous year, but intervalled; so take the mid-point
replace hours = uhrswork*7 if wkswork2==1 & uhrswork!=0 & year>2007 & year<=2018
replace hours = uhrswork*20 if wkswork2==2 & uhrswork!=0 & year>2007 & year<=2018
replace hours = uhrswork*33 if wkswork2==3 & uhrswork!=0 & year>2007 & year<=2018
replace hours = uhrswork*43.5 if wkswork2==4 & uhrswork!=0 & year>2007 & year<=2018
replace hours = uhrswork*48.5 if wkswork2==5 & uhrswork!=0 & year>2007 & year<=2018
replace hours = uhrswork*51 if wkswork2==6 & uhrswork!=0 & year>2007 & year<=2018
label var hours "annual hours"

*** hourly wage measure ***
gen wage=incwage_top/hours  


************************************************************
*** Age restriction
drop if age<20 | (age>64 & age<.)

*** Drop if in the military
drop if (empstatd == 13 | empstatd == 14 | empstatd == 15)

*** Drop if institutionalized
drop if gq ==3
************************************************************


*** Male and female dummies
gen male=1 if sex==1 
replace male=0 if sex==2
gen female=1-male

*** Generate race/ethnicity dummies
gen black=1 if race==2 
replace black=0 if race!=2
gen other=1 if race>=3 & race<=9 
replace other=0 if race<3 

*** Generate native-born dummy
gen native=1 if bpl<=56
replace native=0 if bpl>56

	
************************************************************
*** Keep occ non-missing only for those who are employed ***
************************************************************
* This is so that wages, etc for an occupation is only computed among employed people
replace occ1990dd=. if empstat!=1


*** Data restrictions ***

*** drop farming occupations ***
drop if occ1990dd>=473 & occ1990dd<=498 

*** drop military ***
drop if occ1990dd==905 

	
******************************
*** Occ Code Modifications ***
******************************
* There are 11 occ1990dd codes that do not appear in the 2016 ACS;
* This is because the ACS occupation codes used in 2016 are slightly
* more aggregated than the Census occ2010 codes.
* In order to work with a consistent set of codes, we re-assign workers
* with those occupation codes to a closely related occ1990dd code
replace occ1990dd=579 if occ1990dd==583
replace occ1990dd=634 if occ1990dd==644
replace occ1990dd=634 if occ1990dd==645
replace occ1990dd=707 if occ1990dd==703
replace occ1990dd=707 if occ1990dd==708
replace occ1990dd=707 if occ1990dd==709
replace occ1990dd=719 if occ1990dd==723
replace occ1990dd=719 if occ1990dd==724
replace occ1990dd=744 if occ1990dd==745
replace occ1990dd=763 if occ1990dd==764
replace occ1990dd=824 if occ1990dd==825



*** Add in CPI99 
	* Data record income for the previois year (so e.g. for 2000 use 1999 CPI)
gen cpi99=2.2950001 if year==1980
replace cpi99=1 if year==2000
replace cpi99=0.702818881 if year==2016

*** Real wages ***
gen rw = wage*cpi99

*** Replace zero wages with missing ***
replace rw=. if rw<=0

* Exclude those who worked less than 250 annual hours
replace rw=. if hours<250

*** Log wages ***
gen logrw=ln(rw)


*** Indicator for employed ***
gen emp=(empstat==1)

*** Drop unnecessary variables
drop gq race hispan bpl educd empstatd wkswork* uhrswork 

save "Built/main_dataset_clean", replace


